"""Parse HangSeng eStatement to CSV.
"""
__copyright__ = "Copyright (C) 2019 Cheong Yiu Fung"
__license__ = "GNU GPLv3"

import argparse
import csv
import os

from beancount.ingest.cache import _FileMemo
from beancount_hangseng.Savings import HangSengSavingsImporter


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('-o', '--output', default=None,
                        help="Output path")
    parser.add_argument('-c', '--currency', default="HKD",
                        help="Output path")
    parser.add_argument('filename', help='PDF eStatement to load.')

    args = parser.parse_args()
    allrecords = HangSengSavingsImporter("Assets:HK:HangSeng:Savings", args.currency).extract(_FileMemo(args.filename))

    if args.output is None:
        args.output = os.path.splitext(os.path.basename(args.filename))[0] + ".csv"
        print("Output path not defined, export to {}".format(args.output))

    with open(args.output, mode='w') as csv_file:
        csv_writer = csv.writer(csv_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
        csv_writer.writerow(["date", "account", "amount"])
        for txn in allrecords:
            csv_writer.writerow([txn.date.isoformat(), txn.payee, txn.postings[0].units])
        return 0


if __name__ == '__main__':
    main()



import subprocess


def is_pdftotext_installed():
    """Return true if the external tool pdftotext is installed."""
    try:
        returncode = subprocess.call(['pdftotext', '-h'],
                                     stdout=subprocess.PIPE,
                                     stderr=subprocess.PIPE)
    except (FileNotFoundError, PermissionError):
        return False
    else:
        return returncode == 0


def pdf_to_text(filename):
    """Convert a PDF file to a text equivalent.

    Args:
      filename: A string path, the filename to convert.
    Returns:
      A string, the text contents of the filename.
    """
    pipe = subprocess.Popen(['pdftotext', '-layout', filename, '-'],
                            stdout=subprocess.PIPE,
                            stderr=subprocess.PIPE)
    stdout, stderr = pipe.communicate()
    if stderr:
        raise ValueError(stderr.decode())
    return stdout.decode()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="beancount-hangseng",
    version="0.0.7",
    author="Cheong Yiu Fung",
    author_email="mail@yiufung.net",
    description="Parse Hang Seng eStatements to Beancount/CSV",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/yiufung/beancount-hangseng",
    install_requires=['beancount'],
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Topic :: Office/Business :: Financial :: Accounting",
        "Topic :: Office/Business :: Financial :: Spreadsheet",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
)
